@@ -22,6 +22,7 @@
 
 #include "config.h"
 #include "element.h"
+#include "xml-utils.h"
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
@@ -84,7 +85,7 @@ EltTable Table;
 
 EltTable::EltTable()
 {
-	bindtextdomain (GETTEXT_PACKAGE, DATADIR"/locale");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 #ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
@@ -100,7 +101,7 @@ EltTable::EltTable()
 	Langs["it"] = _("Italian");
 	Langs["pl"] = _("Polish");
 	Langs["ru"] = _("Russian");
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/elements.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/elements.xml")))
 	{
 		g_error (_("Can't find and read elements.xml"));
 	}
@@ -305,19 +306,11 @@ Element::Element(int Z, const char* Symbol)
 Element::~Element()
 {
 	while (!m_radii.empty()) {
-		GcuAtomicRadius *radius = m_radii.back();
-		if (radius) {
-			if (radius->scale) g_free(radius->scale);
-			delete radius;
-		}
+		delete m_radii.back();
 		m_radii.pop_back();
 	}
 	while (!m_en.empty()) {
-		GcuElectronegativity* en = m_en.back();
-		if (en) {
-			if (en->scale) g_free(en->scale);
-			delete en;
-		}
+		delete m_en.back();
 		m_en.pop_back();
 	}
 	while (!m_isotopes.empty ()) {
@@ -432,7 +425,7 @@ void Element::LoadRadii ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/radii.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/radii.xml")))
 	{
 		g_error (_("Can't find and read radii.xml"));
 	}
@@ -532,7 +525,7 @@ void Element::LoadElectronicProps ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/elecprops.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/elecprops.xml")))
 	{
 		g_error (_("Can't find and read elecprops.xml"));
 	}
@@ -558,7 +551,7 @@ void Element::LoadElectronicProps ()
 					en->Z = Z;	//FIXME: is it really useful there?
 					buf = (char*) xmlGetProp (child, (xmlChar*) "scale");
 					if (buf) {
-						en->scale = g_strdup (buf);
+						en->scale = GetStaticScale (buf);
 						xmlFree (buf);
 					} else
 						en->scale = NULL;
@@ -690,7 +683,7 @@ void Element::LoadIsotopes ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/isotopes.xml")))
+	if (!(xml = xmlParseFile (PKGDATADIR"/isotopes.xml")))
 	{
 		g_error (_("Can't find and read isotopes.xml"));
 	}
@@ -902,6 +895,12 @@ void Element::LoadBODR ()
 								elt->props[(strncmp (buf, "bo:", 3))? buf: buf + 3] = val;
 							xmlFree (buf);
 						} else if (!strcmp (buf, "xsd:String") || !strcmp (buf, "xsd:string")) {
+							buf = (char*) xmlGetProp (child, (xmlChar const*) "dictRef");
+							char *val = (char*) xmlNodeGetContent (child);
+							if (elt)
+								elt->sprops[(strncmp (buf, "bo:", 3))? buf: buf + 3] = val;
+							xmlFree (buf);
+							xmlFree (val);
 						} else if (!strcmp (buf, "xsd:int") || !strcmp (buf, "xsd:Integer")) {
 							xmlFree (buf);
 							buf = (char*) xmlNodeGetContent (child);
@@ -910,8 +909,19 @@ void Element::LoadBODR ()
 							buf = (char*) xmlGetProp (child, (xmlChar const*) "dictRef");
 							if (!strcmp (buf, "bo:atomicNumber"))
 								elt = Table[val];
+							else if (elt)
+								elt->iprops[(strncmp (buf, "bo:", 3))? buf: buf + 3] = val;
 							xmlFree (buf);
 						} else if (!strcmp (buf, "xsd:date")) {
+							// assumeing only the discovery year is useful for us
+							xmlFree (buf);
+							buf = (char*) xmlNodeGetContent (child);
+							int val = strtol (buf, NULL, 10);
+							xmlFree (buf);
+							buf = (char*) xmlGetProp (child, (xmlChar const*) "dictRef");
+							if (!strcmp (buf, "bo:discoveryDate"))
+								elt->iprops["discoveryDate"] = val;
+							xmlFree (buf);
 						}
 					}
 					if (props.size () > 0) {
@@ -931,3 +941,9 @@ void Element::LoadBODR ()
 	g_free (old_num_locale);
 }
 #endif
+
+int Element::GetIntegerProperty (char const *property_name)
+{
+	map<string, int>::iterator i = iprops.find (property_name);
+	return (i == iprops.end ())? GCU_ERROR: (*i).second;
+}
