@@ -4,9 +4,7 @@
  * Gnome Chemistry Utils
  * element.h 
  *
- * Copyright (C) 2002-2006
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,6 +31,9 @@
 #include <vector>
 #include "chemistry.h"
 #include "isotope.h"
+#include "value.h"
+
+#define GCU_ERROR (1 << (sizeof(int) - 1))
 
 using namespace std;
 
@@ -152,6 +153,12 @@ public:
 	Loads the isotopes database.
 	*/
 	static void LoadIsotopes ();
+#ifdef WITH_BODR
+	/*!
+	Loads the Blue Obelisk Database.
+	*/
+	static void LoadBODR ();
+#endif
 	/*!
 	Loads all databases.
 	*/
@@ -251,6 +258,27 @@ public:
 	For most elements, only the first is known.
 	*/
 	GcuDimensionalValue const *GetElectronAffinity (unsigned rank = 1);
+	/*!
+	@param property_name: the name of the property as used in the Blue
+	Obelisk Data Repository (without the "bo:" prefix).
+
+	@return the requested property if known, or NULL.
+	*/
+	Value *const GetProperty (char const *property_name) {return props[property_name];}
+	/*!
+	@param property_name: the name of the property as used in the Blue
+	Obelisk Data Repository (without the "bo:" prefix).
+
+	@return the requested string property if known as a reference or an empty string.
+	*/
+	string &GetStringProperty (char const *property_name) {return sprops[property_name];}
+	/*!
+	@param property_name: the name of the property as used in the Blue
+	Obelisk Data Repository (without the "bo:" prefix).
+
+	@return the requested integer property if known, or G_MININT32.
+	*/
+	int GetIntegerProperty (char const *property_name);
 
 private:
 	unsigned char m_Z, m_nve, m_tve, m_maxve;
@@ -269,6 +297,9 @@ private:
 	vector<GcuDimensionalValue> m_ei;
 	vector<GcuDimensionalValue> m_ae;
 	map<string, string> names;
+	map<string, Value*> props;
+	map<string, string> sprops;
+	map<string, int> iprops;
 	string ElecConfig;
 };
 
